@@ -1,5 +1,5 @@
 /*
- * Copyright (c) [2004-2014] Novell, Inc.
+ * Copyright (c) [2004-2015] Novell, Inc.
  *
  * All Rights Reserved.
  *
@@ -34,6 +34,7 @@
 #include <map>
 #include <vector>
 #include <stdexcept>
+#include <chrono>
 
 
 namespace snapper
@@ -56,6 +57,8 @@ namespace snapper
 
     string realpath(const string& path);
 
+    string prepend_root_prefix(const string& root_prefix, const string& path);
+
     string stringerror(int errnum);
 
     string dirname(const string& name);
@@ -103,7 +106,7 @@ namespace snapper
 
     protected:
 
-	struct timeval start_tv;
+	std::chrono::steady_clock::time_point start_time;
 
     };
 
