@@ -34,13 +34,14 @@ namespace snapper
     {
     public:
 
-	static Filesystem* create(const string& fstype, const string& subvolume);
+	static Filesystem* create(const string& fstype, const string& subvolume,
+				  const string& root_prefix);
 
-	Ext4(const string& subvolume);
+	Ext4(const string& subvolume, const string& root_prefix);
 
 	virtual string fstype() const { return "ext4"; }
 
-	virtual void createConfig(bool add_fstab) const;
+	virtual void createConfig() const;
 	virtual void deleteConfig() const;
 
 	virtual string snapshotDir(unsigned int num) const;
